@@ -78,7 +78,7 @@
 */
 
 /*
- * @(#) $Id: cmds.h 2394 2008-09-05 20:13:57Z josh $
+ * @(#) $Id: cmds.h 3068 2009-08-11 18:27:26Z ataufer $
  */
 
 /*
@@ -107,7 +107,7 @@
 
 #define MAX_LINE_LEN 32768  /* increased from 2048 */
 #define MAXSERVERNAME PBS_MAXSERVERNAME+PBS_MAXPORTNUM+2
-#define PBS_DEPEND_LEN 2040
+#define PBS_DEPEND_LEN 65528 /* increased from 2040 */
 
 extern int optind, opterr;
 extern char *optarg;
