@@ -78,7 +78,7 @@
 */
 
 /*
- * @(#) $Id: server_limits.h 2394 2008-09-05 20:13:57Z josh $
+ * @(#) $Id: server_limits.h 2864 2009-03-30 23:54:12Z ataufer $
  */
 
 /*
@@ -110,7 +110,11 @@
 #define PBS_TCPTIMEOUT          6 /* timeout for pbs-mom tcp connections */
 #define PBS_JOBSTAT_MIN         4 /* minimum time between job stats */
 #define PBS_POLLJOBS         TRUE /* enable pbs_server job polling */
-#define PBS_LOG_CHECK_RATE    300 /* check log size every 5 min if log_file_max_size is set */
+#define PBS_LOG_CHECK_RATE    300 /* check log size (and log age) every 5 min
+                                     if log_file_max_size is set */
+#define PBS_ACCT_CHECK_RATE   60*60  /* check accounting files every hour
+																		 if accounting_keep_days is set */
+
 /* Server Database information - path names */
 
 #define PBS_SVR_PRIVATE  "server_priv"
