@@ -98,6 +98,9 @@
 #include <sys/time.h>
 #include <netinet/in.h>
 #include <netdb.h>
+#ifdef sun
+#include <sys/byteorder.h>
+#endif
 #ifdef _AIX
 #include <arpa/inet.h>
 #endif /* _AIX */
@@ -173,8 +176,7 @@ static int  event_count = 0;
 ** Find an event number or return a NULL.
 */
 static event_info *
-find_event(x)
-tm_event_t x;
+find_event(tm_event_t x)
   {
   event_info *ep;
 
@@ -249,7 +251,7 @@ del_event(event_info *ep)
 ** Create a new event number.
 */
 static tm_event_t
-new_event()
+new_event(void)
   {
   static tm_event_t next_event = TM_NULL_EVENT + 1;
   event_info  *ep;
@@ -279,11 +281,7 @@ new_event()
 ** Link new event number into the above hash table.
 */
 static void
-add_event(event, node, type, info)
-tm_event_t  event;
-tm_node_id  node;
-int   type;
-void  *info;
+add_event(tm_event_t event, tm_node_id node, int type, void *info)
   {
   event_info  *ep, **head;
 
@@ -330,8 +328,7 @@ static task_info *task_hash[TASK_HASH];
 ** Find a task table entry for a given task number or return a NULL.
 */
 static task_info *
-find_task(x)
-tm_task_id x;
+find_task(tm_task_id x)
   {
   task_info *tp;
 
@@ -349,10 +346,7 @@ tm_task_id x;
 ** table.
 */
 static tm_task_id
-new_task(jobid, node, task)
-char *jobid;
-tm_node_id node;
-tm_task_id task;
+new_task(char *jobid, tm_node_id node, tm_task_id task)
   {
   DOID("new_task")
   task_info  *tp, **head;
@@ -736,18 +730,18 @@ int tm_nodeinfo(
 
   if (!init_done)
     {
-    return(TM_BADINIT);
+    return (TM_BADINIT);
     }
 
   if (node_table == NULL)
     {
-    return(TM_ESYSTEM);
+    return (TM_ESYSTEM);
     }
 
   for (np = node_table; *np != TM_ERROR_NODE; np++)
     n++;  /* how many nodes */
 
-  if ((np = (tm_node_id *)calloc(n,sizeof(tm_node_id)))==NULL)
+  if ((np = (tm_node_id *)calloc(n,sizeof(tm_node_id))) == NULL)
     {
     /* FAILURE - cannot alloc memory */
 
@@ -867,10 +861,11 @@ int tm_spawn(
 ** signified by the handle, <tid>.
 */
 int
-tm_kill(tid, sig, event)
-tm_task_id tid;  /* in  */
-int  sig;  /* in  */
-tm_event_t *event;  /* out */
+tm_kill(
+  tm_task_id tid,  /* in  */
+  int sig,  /* in  */
+  tm_event_t *event  /* out */
+)
   {
   task_info *tp;
 
@@ -906,10 +901,11 @@ tm_event_t *event;  /* out */
 ** dies.
 */
 int
-tm_obit(tid, obitval, event)
-tm_task_id  tid;  /* in  */
-int  *obitval; /* out */
-tm_event_t *event;  /* out */
+tm_obit(
+  tm_task_id tid,  /* in  */
+  int *obitval, /* out */
+  tm_event_t *event  /* out */
+)
   {
   task_info *tp;
 
@@ -950,12 +946,13 @@ struct taskhold
 ** tasks on <node> is available.
 */
 int
-tm_taskinfo(node, tid_list, list_size, ntasks, event)
-tm_node_id node;  /* in  */
-tm_task_id *tid_list; /* out */
-int  list_size; /* in  */
-int  *ntasks; /* out */
-tm_event_t *event;  /* out */
+tm_taskinfo(
+  tm_node_id node,  /* in  */
+  tm_task_id *tid_list, /* out */
+  int list_size, /* in  */
+  int *ntasks, /* out */
+  tm_event_t *event  /* out */
+)
   {
 
   struct taskhold *thold;
@@ -996,9 +993,10 @@ tm_event_t *event;  /* out */
 ** case of an error, it returns TM_ERROR_NODE.
 */
 int
-tm_atnode(tid, node)
-tm_task_id tid;  /* in  */
-tm_node_id *node;  /* out */
+tm_atnode(
+  tm_task_id tid,  /* in  */
+  tm_node_id *node  /* out */
+)
   {
   task_info *tp;
 
@@ -1026,11 +1024,12 @@ struct reschold
 ** <node> is available.  It returns ERROR_EVENT otherwise.
 */
 int
-tm_rescinfo(node, resource, len, event)
-tm_node_id  node;  /* in  */
-char  *resource; /* out */
-int   len;  /* in  */
-tm_event_t  *event;  /* out */
+tm_rescinfo(
+  tm_node_id node,  /* in  */
+  char *resource, /* out */
+  int len,  /* in  */
+  tm_event_t *event  /* out */
+)
   {
 
   struct reschold *rhold;
@@ -1071,11 +1070,12 @@ tm_event_t  *event;  /* out */
 ** is complete.  It returns ERROR_EVENT otherwise.
 */
 int
-tm_publish(name, info, len, event)
-char *name;  /* in  */
-void *info;  /* in  */
-int  len;  /* in  */
-tm_event_t *event;  /* out */
+tm_publish(
+  char *name,  /* in  */
+  void *info,  /* in  */
+  int len,  /* in  */
+  tm_event_t *event  /* out */
+)
   {
 
   if (!init_done)
@@ -1112,13 +1112,14 @@ struct infohold
 ** string specifying the info posted by <tid> is available.
 */
 int
-tm_subscribe(tid, name, info, len, info_len, event)
-tm_task_id  tid;  /* in  */
-char  *name;  /* in  */
-void  *info;  /* out */
-int   len;  /* in  */
-int   *info_len; /* out */
-tm_event_t  *event;  /* out */
+tm_subscribe(
+  tm_task_id tid,  /* in  */
+  char *name,  /* in  */
+  void *info,  /* out */
+  int len,  /* in  */
+  int *info_len, /* out */
+  tm_event_t *event  /* out */
+)
   {
   task_info  *tp;
 
@@ -1209,9 +1210,7 @@ tm_notify(int tm_signal)
 ** tm_alloc() - make a request for additional resources.
 */
 int
-tm_alloc(resources, event)
-char *resources;
-tm_event_t *event;
+tm_alloc(char *resources, tm_event_t *event)
   {
   if (!init_done)
     return TM_BADINIT;
@@ -1223,9 +1222,7 @@ tm_event_t *event;
 ** tm_dealloc() - drop a node from the job.
 */
 int
-tm_dealloc(node, event)
-tm_node_id node;
-tm_event_t *event;
+tm_dealloc(tm_node_id node, tm_event_t *event)
   {
   if (!init_done)
     return TM_BADINIT;
@@ -1237,8 +1234,7 @@ tm_event_t *event;
 ** tm_create_event() - create a persistent event.
 */
 int
-tm_create_event(event)
-tm_event_t *event;
+tm_create_event(tm_event_t *event)
   {
   if (!init_done)
     return TM_BADINIT;
@@ -1250,8 +1246,7 @@ tm_event_t *event;
 ** tm_destroy_event() - destroy a persistent event.
 */
 int
-tm_destroy_event(event)
-tm_event_t *event;
+tm_destroy_event(tm_event_t *event)
   {
   if (!init_done)
     return TM_BADINIT;
@@ -1264,9 +1259,7 @@ tm_event_t *event;
 **  from the task manager.
 */
 int
-tm_register(what, event)
-tm_whattodo_t *what;
-tm_event_t  *event;
+tm_register(tm_whattodo_t *what, tm_event_t *event)
   {
   if (!init_done)
     return TM_BADINIT;
