@@ -176,6 +176,13 @@ netcounter_incr(void)
     }
   }
 
+
+int get_num_connections()
+  {
+  return(num_connections);
+  }
+
+
 int *
 netcounter_get(void)
   {
@@ -245,7 +252,10 @@ int init_network(
 
   struct sockaddr_un unsocname;
   int unixsocket;
+  memset(&unsocname, 0, sizeof(unsocname));
 #endif
+ 
+  memset(&socname, 0, sizeof(socname));
 
   if (initialized == 0)
     {
@@ -331,7 +341,7 @@ int init_network(
 
     unsocname.sun_family = AF_UNIX;
 
-    strncpy(unsocname.sun_path, TSOCK_PATH, 107);  /* sun_path is defined to be 108 bytes */
+    strncpy(unsocname.sun_path, TSOCK_PATH, sizeof(unsocname.sun_path) - 1);  
 
     unlink(TSOCK_PATH);  /* don't care if this fails */
 
@@ -401,6 +411,7 @@ int wait_request(
 
   fd_set selset;
 
+  char id[] = "wait_request";
   char tmpLine[1024];
 
   struct timeval timeout;
@@ -481,6 +492,11 @@ int wait_request(
 
         num_connections--;  /* added by CRI - should this be here? */
 
+        sprintf(tmpLine,"closed connection to fd %d - num_connections=%d (select bad socket)",
+          i,
+          num_connections);
+
+        log_err(-1,id,tmpLine);
         }
       }
     }    /* END for (i) */
@@ -514,7 +530,7 @@ int wait_request(
 
     /* NOTE:  add info about node associated with connection - NYI */
 
-    snprintf(tmpLine, sizeof(tmpLine), "connection %d to host %s has timed out out after %d seconds - closing stale connection\n",
+    snprintf(tmpLine, sizeof(tmpLine), "connection %d to host %s has timed out after %d seconds - closing stale connection\n",
              i,
              PAddrToString(&cp->cn_addr),
              PBS_NET_MAXCONNECTIDLE);
@@ -634,15 +650,30 @@ void add_conn(
 
 #ifndef NOPRIVPORTS
 
-  if (socktype == PBS_SOCK_INET && port < IPPORT_RESERVED)
+  if ((socktype == PBS_SOCK_INET) && (port < IPPORT_RESERVED))
+    {
     svr_conn[sock].cn_authen = PBS_NET_CONN_FROM_PRIVIL;
+    }
   else
+    {
+    /* AF_UNIX sockets */
     svr_conn[sock].cn_authen = 0;
+    }
 
 #else /* !NOPRIVPORTS */
-  svr_conn[sock].cn_authen = PBS_NET_CONN_FROM_PRIVIL;
 
-#endif /* NOPRIVPORTS */
+  if (socktype == PBS_SOCK_INET)
+    {
+    /* All TCP connections are privileged */
+    svr_conn[sock].cn_authen = PBS_NET_CONN_FROM_PRIVIL;
+    }
+  else
+    {
+    /* AF_UNIX sockets */
+    svr_conn[sock].cn_authen = 0;
+    }
+
+#endif /* !NOPRIVPORTS */
 
   return;
   }  /* END add_conn() */
