@@ -1335,9 +1335,9 @@ static void preobit_reply(
 
       /* do this if not interactive */
 
-      unlink(std_file_name(pjob, StdOut, &x));
-      unlink(std_file_name(pjob, StdErr, &x));
-      unlink(std_file_name(pjob, Chkpt, &x));
+      job_unlink_file(pjob, std_file_name(pjob, StdOut, &x));
+      job_unlink_file(pjob, std_file_name(pjob, StdErr, &x));
+      job_unlink_file(pjob, std_file_name(pjob, Chkpt, &x));
       }
 
     mom_deljob(pjob);
@@ -1566,9 +1566,9 @@ static void obit_reply(
             {
             /* do this if not interactive */
 
-            unlink(std_file_name(pjob, StdOut, &x));
-            unlink(std_file_name(pjob, StdErr, &x));
-            unlink(std_file_name(pjob, Chkpt, &x));
+            job_unlink_file(pjob, std_file_name(pjob, StdOut, &x));
+            job_unlink_file(pjob, std_file_name(pjob, StdErr, &x));
+            job_unlink_file(pjob, std_file_name(pjob, Chkpt, &x));
             }
 
           mom_deljob(pjob);
