@@ -449,8 +449,8 @@ proc_stat_t *get_proc_stat(
 
 
 
-proc_mem_t *
-get_proc_mem(void)
+
+proc_mem_t *get_proc_mem(void)
 
   {
   static proc_mem_t   mm;
@@ -458,21 +458,21 @@ get_proc_mem(void)
   char                str[32];
   unsigned long long  bfsz, casz;
 
-  if ((fp = fopen("/proc/meminfo", "r")) == NULL)
+  if ((fp = fopen("/proc/meminfo","r")) == NULL)
     {
     return(NULL);
     }
 
-  if (fscanf(fp, "%30s", str) != 1)
+  if (fscanf(fp,"%30s",str) != 1)
     {
     return(NULL);
     }
 
-  if (!strncmp(str, "total:", sizeof(str)))
+  if (!strncmp(str,"total:",sizeof(str)))
     {
     /* old format */
 
-    if (fscanf(fp, "%*[^\n]%*c") != 0)     /* remove text header */
+    if (fscanf(fp,"%*[^\n]%*c") != 0)     /* remove text header */
       {
       return(NULL);
       }
@@ -628,8 +628,7 @@ get_proc_mem(void)
 
 
 
-void
-dep_initialize(void)
+void dep_initialize(void)
 
   {
   char *id = "dep_initialize";
@@ -981,6 +980,7 @@ static unsigned long long mem_sum(
 
 
 
+
 /*
  * Internal session workingset size function.
  */
@@ -2311,7 +2311,7 @@ int kill_task(
 
     ct++;
 
-    /* do code to mark task as finished (borrowed from Linux scan_for_terminating())... */
+    /* do code to mark task as finished (borrowed from Linux scan_for_terminated())... */
 
     ptask->ti_qs.ti_exitstat = 0;  /* assume successful completion */
     ptask->ti_qs.ti_status   = TI_STATE_EXITED;
@@ -2338,7 +2338,7 @@ int kill_task(
 
     ct++;
 
-    /* do code to mark task as finished (borrowed from Linux scan_for_terminating())... */
+    /* do code to mark task as finished (borrowed from Linux scan_for_terminated())... */
 
     ptask->ti_qs.ti_exitstat = 0;  /* assume successful completion */
     ptask->ti_qs.ti_status   = TI_STATE_EXITED;
@@ -3074,7 +3074,7 @@ char *sessions(
     if ((jobid = ps->session) == 0)
       continue;
 
-    if (LOGLEVEL >= 6)
+    if (LOGLEVEL >= 7)
       {
       sprintf(log_buffer, "%s[%d]: pid %d sid %d",
               id,
@@ -3247,7 +3247,7 @@ char *pids(
     {
     ps = &proc_array[i];
 
-    if (LOGLEVEL >= 6)
+    if (LOGLEVEL >= 7)
       {
       DBPRT(("%s[%d]: pid: %d  sid: %d\n",
              id,
@@ -3320,7 +3320,7 @@ char *nusers(
     if ((uid = ps->uid) == 0)
       continue;
 
-    if (LOGLEVEL >= 6)
+    if (LOGLEVEL >= 7)
       {
       sprintf(log_buffer, "%s[%d]: pid %d uid %d",
               id,
