@@ -393,7 +393,7 @@ int run_pelog(
           (pelog != NULL) ? pelog : "NULL",
           (pjob != NULL) ? pjob->ji_qs.ji_jobid : "NULL",
           getcwd(tmpBuf, sizeof(tmpBuf)),
-          getpid());
+          (int)getpid());
 
         log_record(PBSEVENT_SYSTEM, 0, id, log_buffer);
         }
@@ -708,7 +708,7 @@ int run_pelog(
 
     /* NOTE:  inside child */
 
-    if (which == PE_EPILOG)
+    if (which == PE_EPILOG || which == PE_EPILOGUSER)
       {
       /* for epilog only */
 
