@@ -673,7 +673,7 @@ static int return_file(
   close(fds);
 
   if (rc == 0)
-    unlink(filename);
+    job_unlink_file(pjob, filename);
 
   return(rc);
   }  /* END return_file() */
