@@ -2010,7 +2010,6 @@ found:
         log_event(PBSEVENT_ADMIN, PBS_EVENTCLASS_SERVER, id, log_buffer);
         }
 
-#ifndef ALT_CLSTR_ADDR
       ret = is_compose(stream, IS_CLUSTER_ADDRS);
 
       if (ret != DIS_SUCCESS)
@@ -2037,7 +2036,7 @@ found:
       /* rpp_eom(stream); */
 
       /* CLUSTER_ADDRS successful */
-#endif
+
       node->nd_state &= ~(INUSE_NEEDS_HELLO_PING);
 
       break;
@@ -2723,7 +2722,7 @@ static int number(
   int i = 0;
   char *str = *ptr;
 
-  while (isdigit(*str))
+  while (isdigit(*str) && (unsigned int)(i + 1) < sizeof holder)
     holder[i++] = *str++;
 
   if (i == 0)
@@ -2733,7 +2732,7 @@ static int number(
 
   holder[i] = '\0';
 
-  if ((i = atoi(holder)) == 0)
+  if ((i = atoi(holder)) <= 0)
     {
     sprintf(log_buffer, "zero illegal");
 
