@@ -533,7 +533,13 @@ int pbsd_init(
 
   if (svr_resc_def == NULL)
     {
-    init_resc_defs();
+    rc = init_resc_defs();
+    if (rc != 0)
+      {
+        log_err(rc, "pbsd_init", msg_init_baddb);
+
+        return(-1);
+      }
     }
 
 #if !defined(DEBUG) && !defined(NO_SECURITY_CHECK)
@@ -1646,7 +1652,7 @@ static void catch_child(
         msg_daemonname,
         log_buffer);
 #else
-      DBPRT(("catch_child caught pid %d\n", pid));
+      DBPRT(("catch_child caught pid %d\n", (int)pid));
 #endif
       }
 
@@ -1677,7 +1683,7 @@ static void catch_child(
             msg_daemonname,
             log_buffer);
 #else
-          DBPRT(("catch_child found work task found for pid %d\n", pid));
+          DBPRT(("catch_child found work task found for pid %d\n", (int)pid));
 #endif
           }
 
@@ -1694,7 +1700,7 @@ static void catch_child(
 
       log_err(-1, "catch_child", log_buffer);
 #else
-      DBPRT(("catch_child no work task found for pid %d\n", pid));
+      DBPRT(("catch_child no work task found for pid %d\n", (int)pid));
 #endif
       }
     }    /* END while (1) */
@@ -2086,7 +2092,13 @@ int get_svr_attr(
 
     if (svr_resc_def == NULL)
       {
-      init_resc_defs();
+      rc = init_resc_defs();
+      if (rc != 0)
+        {
+        log_err(rc, "pbsd_init", msg_init_baddb);
+
+        return(-1);
+        }
       }
 
     if (((rc = chk_save_file(path_svrdb))!= 0) || ((rc = svr_recov(path_svrdb, TRUE)) == -1)) 
