@@ -141,6 +141,7 @@ extern void svr_shutdown(int);
 extern void acct_close(void);
 extern int  svr_startjob A_((job *, struct batch_request *, char *, char *));
 extern int RPPConfigure(int, int);
+extern void acct_cleanup(long);
 #ifdef NO_SIGCHLD
 extern void check_children();
 #endif
@@ -151,6 +152,10 @@ extern void check_children();
 extern int    svr_chngNodesfile;
 extern int    svr_totnodes;
 
+/* External Functions */
+
+extern int    get_svr_attr (int);
+
 /* Local Private Functions */
 
 static int    get_port A_((char *, unsigned int *, pbs_net_t *));
@@ -167,14 +172,15 @@ char        *log_file  = NULL;
 char        *path_home = PBS_SERVER_HOME;
 char        *path_acct;
 char         path_log[MAXPATHLEN + 1];
-char        *path_priv;
+char        *path_priv = NULL;
 char        *path_arrays;
 char        *path_jobs;
 char        *path_queues;
 char        *path_spool;
-char        *path_svrdb;
+char        *path_svrdb = NULL;
 char        *path_svrdb_new;
-char         *path_track;
+char        *path_svrlog;
+char        *path_track;
 char        *path_nodes;
 char        *path_nodes_new;
 char        *path_nodestate;
@@ -193,6 +199,7 @@ extern pbs_net_t pbs_server_addr;
 unsigned int pbs_server_port_dis;
 listener_connection listener_conns[MAXLISTENERS];
 int  queue_rank = 0;
+int a_opt_init = -1;
 
 struct server server;  /* the server structure */
 char         server_host[PBS_MAXHOSTNAME + 1]; /* host_name */
@@ -517,6 +524,7 @@ int main(
   void ping_nodes A_((struct work_task *));
   void check_nodes A_((struct work_task *));
   void check_log A_((struct work_task *));
+  void check_acct_log A_((struct work_task *));
 
   char   EMsg[1024];
 
@@ -734,6 +742,7 @@ int main(
 
           exit(1);
           }
+        a_opt_init = server.sv_attr[(int)SRV_ATR_scheduling].at_val.at_long;
 
         break;
 
@@ -1010,11 +1019,37 @@ int main(
     }
 
 
-  /* make sure no other server is running with this home directory */
+  /*
+   * Read in server attributes so they are available to be used
+   * Attributes will not be read in on a pbs_server -t create
+   */
 
-  sprintf(lockfile, "%s/%s/server.lock",
-          path_home,
-          PBS_SVR_PRIVATE);
+  if (get_svr_attr(server_init_type) == -1)
+    {
+    fprintf(stderr,"%s: failed to get server attributes\n", 
+      ProgName);
+
+    return(1);
+    }
+
+  /*
+   * make sure no other server is running with this home directory.
+   * If server lockfile attribute has been set use it.
+   * If not use default location for it
+   */
+   
+  if ((server.sv_attr[(int)SRV_ATR_lockfile].at_flags & ATR_VFLAG_SET) &&
+               (server.sv_attr[(int)SRV_ATR_lockfile].at_val.at_str))
+    {
+    sprintf(lockfile,"%s",
+      server.sv_attr[(int)SRV_ATR_lockfile].at_val.at_str);
+    }
+  else
+    {
+    sprintf(lockfile,"%s/%s/server.lock",
+      path_home,
+      PBS_SVR_PRIVATE);
+    }
 
   if ((lockfds = open(lockfile, O_CREAT | O_TRUNC | O_WRONLY, 0600)) < 0)
     {
@@ -1048,6 +1083,13 @@ int main(
         }
       }
 
+	if ((sid = setsid()) == -1)
+      {
+      log_err(errno, msg_daemonname, "setsid failed");
+
+      exit(2);
+      }
+
     while (try_lock_out(lockfds, F_WRLCK))
       sleep(TSERVER_HA_CHECK_TIME); /* Relinquish */
     }
@@ -1281,6 +1323,8 @@ int main(
 
   set_task(WORK_Timed, time_now + 5, check_log, NULL);
 
+  set_task(WORK_Timed,time_now + 10,check_acct_log,NULL);
+
   /*
    * Now at last, we are ready to do some batch work.  The
    * following section constitutes the "main" loop of the server
@@ -1492,6 +1536,27 @@ void check_log(
   {
   long depth = 1;
 
+ /* remove logs older than LogKeepDays */
+
+ if ((server.sv_attr[(int)SRV_ATR_LogKeepDays].at_flags 
+     & ATR_VFLAG_SET) != 0)
+   {
+   snprintf(log_buffer,sizeof(log_buffer),"checking for old pbs_server logs in dir '%s' (older than %ld days)",
+     path_svrlog,
+     server.sv_attr[(int)SRV_ATR_LogKeepDays].at_val.at_long);
+ 
+   log_event(
+     PBSEVENT_SYSTEM | PBSEVENT_FORCE,
+     PBS_EVENTCLASS_SERVER,
+     msg_daemonname,
+     log_buffer);
+
+   if (log_remove_old(path_svrlog,server.sv_attr[(int)SRV_ATR_LogKeepDays].at_val.at_long * SECS_PER_DAY) != 0)
+     {
+     log_err(-1,"check_log","failure occurred when checking for old pbs_server logs");
+     }
+   }
+
   if ((server.sv_attr[(int)SRV_ATR_LogFileMaxSize].at_flags
        & ATR_VFLAG_SET) != 0)
     {
@@ -1539,6 +1604,33 @@ void check_log(
 
 
 
+void check_acct_log(
+
+ struct work_task *ptask) /* I */
+
+ {
+  if (((server.sv_attr[(int)SRV_ATR_AcctKeepDays].at_flags & ATR_VFLAG_SET) != 0)
+       && (server.sv_attr[(int)SRV_ATR_AcctKeepDays].at_val.at_long >= 0))
+    {
+    sprintf(log_buffer,"Checking accounting files - keep days = %ld",
+      server.sv_attr[(int)SRV_ATR_AcctKeepDays].at_val.at_long);
+
+    log_event(
+      PBSEVENT_SYSTEM | PBSEVENT_FORCE,
+      PBS_EVENTCLASS_SERVER,
+      msg_daemonname,
+      log_buffer);
+     
+    acct_cleanup(server.sv_attr[(int)SRV_ATR_AcctKeepDays].at_val.at_long);
+    
+    }
+
+  set_task(WORK_Timed,time_now + PBS_ACCT_CHECK_RATE,check_acct_log,NULL);
+
+  return;
+  } /* END check_acct_log */
+
+
 
 
 
