@@ -114,7 +114,7 @@ extern char *msg_manager;
 extern char *msg_unkjobid;
 extern char *msg_permlog;
 extern char *msg_badstate;
-tlist_head	svr_alljobs;           /* list of all jobs in server       */
+extern tlist_head	svr_alljobs;   /* list of all jobs in server       */
 
 extern struct server server;
 extern time_t time_now;
@@ -860,6 +860,12 @@ void remove_job_delete_nanny(
 
   struct work_task *pwtiter, *pwtdel;
 
+  if (pjob->ji_svrtask.ll_next == NULL)
+    {
+    /* no nanny, nothing to delete */
+    return;
+    }
+
   pwtiter = (struct work_task *)GET_NEXT(pjob->ji_svrtask);
 
   while (pwtiter != NULL)
