@@ -88,6 +88,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <time.h>
 #include "libpbs.h"
 #include "server_limits.h"
 #include "list_link.h"
@@ -108,6 +109,7 @@
 
 
 #define RESC_USED_BUF 2048
+#define JOBMUSTREPORTDEFAULTKEEP 30
 
 /* External Global Data Items */
 
@@ -695,6 +697,7 @@ void on_job_exit(
   {
   int    handle = -1;
   job   *pjob;
+  int    rc = 0;
 #ifdef VNODETESTING
   job   *pj;
 #endif
@@ -703,6 +706,8 @@ void on_job_exit(
 
   int    IsFaked = 0;
   int  KeepSeconds = 0;
+  int  PurgeIt = FALSE;
+  int MustReport = FALSE;
   pbs_queue *pque;
 
   extern void remove_job_delete_nanny(struct job *);
@@ -757,7 +762,13 @@ void on_job_exit(
          log_buffer));
 #endif /* END VNODETESTING */
 
-  if ((handle = mom_comm(pjob, on_job_exit)) < 0)
+  /*
+   * we don't need a handle if we are complete. On starting up we will NOT have
+   * a connection to mom, but still want to try and process the completed job
+   */
+  
+  if ((pjob->ji_qs.ji_substate != JOB_SUBSTATE_COMPLETE) &&
+    ((handle = mom_comm(pjob,on_job_exit)) < 0))
     {
     /* FAILURE - cannot connect to mom */
 
@@ -792,7 +803,6 @@ void on_job_exit(
         }
 
       svr_setjobstate(
-
         pjob,
         JOB_STATE_EXITING,
         JOB_SUBSTATE_STAGEOUT);
@@ -1118,7 +1128,19 @@ void on_job_exit(
         {
         strcpy(preq->rq_ind.rq_delete.rq_objname, pjob->ji_qs.ji_jobid);
 
-        issue_Drequest(handle, preq, release_req, 0);
+        rc = issue_Drequest(handle, preq, release_req, 0);
+
+        if (rc != 0)
+          {
+          snprintf(log_buffer, LOG_BUF_SIZE, "DeleteJob issue_Drequest failure, rc = %d",
+                    rc);
+
+          log_event(
+            PBSEVENT_ERROR | PBSEVENT_ADMIN | PBSEVENT_JOB,
+            PBS_EVENTCLASS_JOB,
+            pjob->ji_qs.ji_jobid,
+            log_buffer);
+          }
 
         /* release_req will free preq and close connection */
         }
@@ -1143,7 +1165,7 @@ void on_job_exit(
 
     case JOB_SUBSTATE_COMPLETE:
 
-      if (LOGLEVEL >= 4)
+      if ((LOGLEVEL >= 4) && (ptask->wt_type == WORK_Immed))
         {
         log_event(
           PBSEVENT_JOB,
@@ -1160,18 +1182,72 @@ void on_job_exit(
                         0);
         }
 
+      if (ptask->wt_type == WORK_Immed) 
+        {
+        /* first time in */
+
+        if (((server.sv_attr[(int)SRV_ATR_JobMustReport].at_flags & ATR_VFLAG_SET) != 0)
+          && (server.sv_attr[(int)SRV_ATR_JobMustReport].at_val.at_long > 0))
+          {
+          MustReport = TRUE;
+          pjob->ji_wattr[(int)JOB_ATR_reported].at_val.at_long = 0;
+
+          pjob->ji_wattr[(int)JOB_ATR_reported].at_flags =
+            ATR_VFLAG_SET | ATR_VFLAG_MODIFY;
+
+          job_save(pjob,SAVEJOB_FULL);
+          }
+        }
+      else if (((pjob->ji_wattr[(int)JOB_ATR_reported].at_flags & ATR_VFLAG_SET) != 0)
+        && (pjob->ji_wattr[(int)JOB_ATR_reported].at_val.at_long == 0))
+        {
+        MustReport = TRUE;
+        }
+
       if (KeepSeconds <= 0)
         {
-        job_purge(pjob);
+        if (MustReport)
+          {
+          /*
+           * If job must report is set and keep_completed is 0,
+           * default to JOBMUSTREPORTDEFAULTKEEP seconds
+           */
+          KeepSeconds = JOBMUSTREPORTDEFAULTKEEP;
+          }
+        else
+          {
+          job_purge(pjob);
 
-        break;
+          break;
+          }
         }
 
       if (ptask->wt_type == WORK_Immed)
         {
-        /* first time in */
+        /* is it first time in or server restart recovery */
+        
+        if ((handle == -1) &&
+            (pjob->ji_wattr[(int)JOB_ATR_comp_time].at_flags & ATR_VFLAG_SET))
+          {
+          /*
+           * server restart - if we already have a completion_time then we
+           * better be restarting.
+           * use the comp_time to determine task invocation time
+           */
+          ptask = set_task(WORK_Timed,
+            pjob->ji_wattr[(int)JOB_ATR_comp_time].at_val.at_long + KeepSeconds,
+            on_job_exit, pjob);
+          }
+        else
+          {
+          /* First time in - Set the job completion time */
 
-        ptask = set_task(WORK_Timed, time_now + KeepSeconds, on_job_exit, pjob);
+          pjob->ji_wattr[(int)JOB_ATR_comp_time].at_val.at_long = (long)time(NULL);
+          pjob->ji_wattr[(int)JOB_ATR_comp_time].at_flags |= ATR_VFLAG_SET;
+
+          ptask = set_task(WORK_Timed, time_now + KeepSeconds, on_job_exit, pjob);
+          job_save(pjob, SAVEJOB_FULL);
+          }
 
         if (ptask != NULL)
           {
@@ -1183,8 +1259,44 @@ void on_job_exit(
       else
         {
         /* job has been around long enough */
+        
+        /*
+         * If the jobs must report attribute is set
+         * then skip the job if it has not yet reported to the scheduler.
+         */
+        
+        PurgeIt = TRUE;
 
-        job_purge(pjob);
+        if (((pjob->ji_wattr[(int)JOB_ATR_reported].at_flags & ATR_VFLAG_SET) != 0)
+          && (pjob->ji_wattr[(int)JOB_ATR_reported].at_val.at_long == 0))
+          {
+          if (LOGLEVEL >= 7)
+            {
+            sprintf(log_buffer, "Bypassing job %s waiting for purge completed command",
+              pjob->ji_qs.ji_jobid);
+            log_record(
+              PBSEVENT_JOB,
+              PBS_EVENTCLASS_JOB,
+              pjob->ji_qs.ji_jobid,
+              log_buffer);
+            }
+
+          ptask = set_task(WORK_Timed,time_now +
+                JOBMUSTREPORTDEFAULTKEEP,on_job_exit,pjob);
+
+          if (ptask != NULL)
+            {
+            /* insure that work task will be removed if job goes away */
+
+            append_link(&pjob->ji_svrtask,&ptask->wt_linkobj,ptask);
+            }
+            
+            PurgeIt = FALSE;
+          }
+        if (PurgeIt)
+          {
+          job_purge(pjob);
+          }
         }
 
       break;
@@ -1215,6 +1327,7 @@ void on_job_rerun(
   int        handle;
   int        newstate;
   int        newsubst;
+  int        rc = 0;
   job       *pjob;
 
   struct batch_request *preq;
@@ -1543,7 +1656,19 @@ void on_job_rerun(
 
         preq->rq_extra = (void *)pjob;
 
-        issue_Drequest(handle, preq, release_req, 0);
+        rc = issue_Drequest(handle, preq, release_req, 0);
+
+        if (rc != 0)
+          {
+          snprintf(log_buffer, LOG_BUF_SIZE, "DeleteJob issue_Drequest failure, rc = %d",
+                    rc);
+
+          log_event(
+            PBSEVENT_ERROR | PBSEVENT_ADMIN | PBSEVENT_JOB,
+            PBS_EVENTCLASS_JOB,
+            pjob->ji_qs.ji_jobid,
+            log_buffer);
+          }
 
         /* release_req will free preq and close connection */
         }
@@ -1755,7 +1880,6 @@ void req_jobobit(
       }
 
     req_reject(
-
       bad,
       0,
       preq,
@@ -1830,7 +1954,6 @@ void req_jobobit(
     }
 
   modify_job_attr(
-
     pjob,
     patlist,
     ATR_DFLAG_MGWR | ATR_DFLAG_SvWR,
@@ -1905,7 +2028,6 @@ void req_jobobit(
 
     switch (exitstatus)
       {
-
       case JOB_EXEC_FAIL1:
 
       default:
@@ -2133,7 +2255,6 @@ void req_jobobit(
       }
 
     svr_setjobstate(
-
       pjob,
       JOB_STATE_EXITING,
       pjob->ji_qs.ji_substate);
